@@ -20,6 +20,8 @@
  *   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA              *
  *****************************************************************************/
 
+#include "fileviewdropboxplugin.h"
+
 #include <KFileItem>
 #include <KFileItemListProperties>
 #include <KLocalizedString>
@@ -32,8 +34,6 @@
 #include <QFileSystemWatcher>
 #include <QStringBuilder>
 
-#include "fileviewdropboxplugin.h"
-
 K_PLUGIN_FACTORY(FileViewDropboxPluginFactory, registerPlugin<FileViewDropboxPlugin>();)
 
 class FileViewDropboxPlugin::Private
@@ -146,7 +146,7 @@ QList<QAction*> FileViewDropboxPlugin::actions(const KFileItemList& items) const
 
     // analyze item options and dynamically form a menu
     foreach (const QString& replyLine, reply) {
-        const QStringList options = replyLine.split("~");
+        const QStringList options = replyLine.split('~');
 
         if (options.count() > 2) {
             QAction* action = d->contextActions->addAction(options.at(2));
@@ -217,4 +217,4 @@ bool FileViewDropboxPlugin::connectWithDropbox(const QPointer<QLocalSocket>& soc
     return true;
 }
 
-#include "fileviewdropboxplugin.moc"
\ No newline at end of file
+#include "fileviewdropboxplugin.moc"
